==> haskell-deferred-folds-0.9.18.6-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deferred-folds
version:              0.9.18.6
visibility:           public
id:                   deferred-folds-0.9.18.6-EC51AuSlEFy66BGe6tsCu3
key:                  deferred-folds-0.9.18.6-EC51AuSlEFy66BGe6tsCu3
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
stability:            Experimental
homepage:             https://github.com/nikita-volkov/deferred-folds
synopsis:             Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.

category:             Folding
abi:                  dbe600b11b15c39b14e7e460278de76e
exposed:              True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr

hidden-modules:
    DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
    DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
    DeferredFolds.Prelude DeferredFolds.Types DeferredFolds.UnfoldrM
    DeferredFolds.Util.TextArray

import-dirs:          /usr/lib/ghc-9.2.8/site-local/deferred-folds-0.9.18.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/deferred-folds-0.9.18.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deferred-folds
hs-libraries:         HSdeferred-folds-0.9.18.6-EC51AuSlEFy66BGe6tsCu3
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    foldl-1.4.16-IF8ULSXvycR9FgCW8DMW6c
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    primitive-0.7.4.0-IuAkHfsD4drDvErljoigXB text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-B4pxT3iF0jR7WvKg6foz6h
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe

haddock-interfaces:
    /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock

haddock-html:         /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deferred-folds-0.9.18.6-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deferred-folds
version:              0.9.18.6
visibility:           public
id:                   deferred-folds-0.9.18.6-GquzRpErrnl11ZQrZBo5e1
key:                  deferred-folds-0.9.18.6-GquzRpErrnl11ZQrZBo5e1
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
stability:            Experimental
homepage:             https://github.com/nikita-volkov/deferred-folds
synopsis:             Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.

category:             Folding
abi:                  22ae846d0679f7aadfe3fcde1a93ba6f
exposed:              True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr

hidden-modules:
    DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
    DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
    DeferredFolds.Prelude DeferredFolds.Types DeferredFolds.UnfoldrM
    DeferredFolds.Util.TextArray

import-dirs:          /usr/lib/ghc-9.2.8/site-local/deferred-folds-0.9.18.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/deferred-folds-0.9.18.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deferred-folds
hs-libraries:         HSdeferred-folds-0.9.18.6-GquzRpErrnl11ZQrZBo5e1
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    foldl-1.4.16-1BhYcKLm1507ZwegSL0d1V
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    primitive-0.7.4.0-IuAkHfsD4drDvErljoigXB text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe

haddock-interfaces:
    /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock

haddock-html:         /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
